Class: Aws::ChimeSDKIdentity::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ChimeSDKIdentity::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-chimesdkidentity/client.rb,
sig/client.rbs
Overview
An API client for ChimeSDKIdentity. To construct a client, you need to configure a :region and :credentials.
client = Aws::ChimeSDKIdentity::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateAppInstanceAdminResponseSuccess, _CreateAppInstanceBotResponseSuccess, _CreateAppInstanceResponseSuccess, _CreateAppInstanceUserResponseSuccess, _DescribeAppInstanceAdminResponseSuccess, _DescribeAppInstanceBotResponseSuccess, _DescribeAppInstanceResponseSuccess, _DescribeAppInstanceUserEndpointResponseSuccess, _DescribeAppInstanceUserResponseSuccess, _GetAppInstanceRetentionSettingsResponseSuccess, _ListAppInstanceAdminsResponseSuccess, _ListAppInstanceBotsResponseSuccess, _ListAppInstanceUserEndpointsResponseSuccess, _ListAppInstanceUsersResponseSuccess, _ListAppInstancesResponseSuccess, _ListTagsForResourceResponseSuccess, _PutAppInstanceRetentionSettingsResponseSuccess, _PutAppInstanceUserExpirationSettingsResponseSuccess, _RegisterAppInstanceUserEndpointResponseSuccess, _UpdateAppInstanceBotResponseSuccess, _UpdateAppInstanceResponseSuccess, _UpdateAppInstanceUserEndpointResponseSuccess, _UpdateAppInstanceUserResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_app_instance(params = {}) ⇒ Types::CreateAppInstanceResponse
Creates an Amazon Chime SDK messaging
AppInstanceunder an AWS account. -
#create_app_instance_admin(params = {}) ⇒ Types::CreateAppInstanceAdminResponse
Promotes an
AppInstanceUserorAppInstanceBotto anAppInstanceAdmin. -
#create_app_instance_bot(params = {}) ⇒ Types::CreateAppInstanceBotResponse
Creates a bot under an Amazon Chime
AppInstance. -
#create_app_instance_user(params = {}) ⇒ Types::CreateAppInstanceUserResponse
Creates a user under an Amazon Chime
AppInstance. -
#delete_app_instance(params = {}) ⇒ Struct
Deletes an
AppInstanceand all associated data asynchronously. -
#delete_app_instance_admin(params = {}) ⇒ Struct
Demotes an
AppInstanceAdminto anAppInstanceUserorAppInstanceBot. -
#delete_app_instance_bot(params = {}) ⇒ Struct
Deletes an
AppInstanceBot. -
#delete_app_instance_user(params = {}) ⇒ Struct
Deletes an
AppInstanceUser. -
#deregister_app_instance_user_endpoint(params = {}) ⇒ Struct
Deregisters an
AppInstanceUserEndpoint. -
#describe_app_instance(params = {}) ⇒ Types::DescribeAppInstanceResponse
Returns the full details of an
AppInstance. -
#describe_app_instance_admin(params = {}) ⇒ Types::DescribeAppInstanceAdminResponse
Returns the full details of an
AppInstanceAdmin. -
#describe_app_instance_bot(params = {}) ⇒ Types::DescribeAppInstanceBotResponse
The
AppInstanceBot'sinformation. -
#describe_app_instance_user(params = {}) ⇒ Types::DescribeAppInstanceUserResponse
Returns the full details of an
AppInstanceUser. -
#describe_app_instance_user_endpoint(params = {}) ⇒ Types::DescribeAppInstanceUserEndpointResponse
Returns the full details of an
AppInstanceUserEndpoint. -
#get_app_instance_retention_settings(params = {}) ⇒ Types::GetAppInstanceRetentionSettingsResponse
Gets the retention settings for an
AppInstance. -
#list_app_instance_admins(params = {}) ⇒ Types::ListAppInstanceAdminsResponse
Returns a list of the administrators in the
AppInstance. -
#list_app_instance_bots(params = {}) ⇒ Types::ListAppInstanceBotsResponse
Lists all
AppInstanceBotscreated under a singleAppInstance. -
#list_app_instance_user_endpoints(params = {}) ⇒ Types::ListAppInstanceUserEndpointsResponse
Lists all the
AppInstanceUserEndpointscreated under a singleAppInstanceUser. -
#list_app_instance_users(params = {}) ⇒ Types::ListAppInstanceUsersResponse
List all
AppInstanceUserscreated under a singleAppInstance. -
#list_app_instances(params = {}) ⇒ Types::ListAppInstancesResponse
Lists all Amazon Chime
AppInstances created under a single AWS account. -
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags applied to an Amazon Chime SDK identity resource.
-
#put_app_instance_retention_settings(params = {}) ⇒ Types::PutAppInstanceRetentionSettingsResponse
Sets the amount of time in days that a given
AppInstanceretains data. -
#put_app_instance_user_expiration_settings(params = {}) ⇒ Types::PutAppInstanceUserExpirationSettingsResponse
Sets the number of days before the
AppInstanceUseris automatically deleted. -
#register_app_instance_user_endpoint(params = {}) ⇒ Types::RegisterAppInstanceUserEndpointResponse
Registers an endpoint under an Amazon Chime
AppInstanceUser. -
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified Amazon Chime SDK identity resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified Amazon Chime SDK identity resource.
-
#update_app_instance(params = {}) ⇒ Types::UpdateAppInstanceResponse
Updates
AppInstancemetadata. -
#update_app_instance_bot(params = {}) ⇒ Types::UpdateAppInstanceBotResponse
Updates the name and metadata of an
AppInstanceBot. -
#update_app_instance_user(params = {}) ⇒ Types::UpdateAppInstanceUserResponse
Updates the details of an
AppInstanceUser. -
#update_app_instance_user_endpoint(params = {}) ⇒ Types::UpdateAppInstanceUserEndpointResponse
Updates the details of an
AppInstanceUserEndpoint.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1720 1721 1722 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1720 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1723 1724 1725 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1723 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1693 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ChimeSDKIdentity') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-chimesdkidentity' context[:gem_version] = '1.60.0' Seahorse::Client::Request.new(handlers, context) end |
#create_app_instance(params = {}) ⇒ Types::CreateAppInstanceResponse
Creates an Amazon Chime SDK messaging AppInstance under an AWS
account. Only SDK messaging customers use this API.
CreateAppInstance supports idempotency behavior as described in the
AWS API Standard.
identity
86 |
# File 'sig/client.rbs', line 86
def create_app_instance: (
|
#create_app_instance_admin(params = {}) ⇒ Types::CreateAppInstanceAdminResponse
Promotes an AppInstanceUser or AppInstanceBot to an
AppInstanceAdmin. The promoted entity can perform the following
actions.
-
ChannelModeratoractions across all channels in theAppInstance. -
DeleteChannelMessageactions.
Only an AppInstanceUser and AppInstanceBot can be promoted to an
AppInstanceAdmin role.
105 |
# File 'sig/client.rbs', line 105
def create_app_instance_admin: (
|
#create_app_instance_bot(params = {}) ⇒ Types::CreateAppInstanceBotResponse
Creates a bot under an Amazon Chime AppInstance. The request
consists of a unique Configuration and Name for that bot.
116 |
# File 'sig/client.rbs', line 116
def create_app_instance_bot: (
|
#create_app_instance_user(params = {}) ⇒ Types::CreateAppInstanceUserResponse
Creates a user under an Amazon Chime AppInstance. The request
consists of a unique appInstanceUserId and Name for that user.
136 |
# File 'sig/client.rbs', line 136
def create_app_instance_user: (
|
#delete_app_instance(params = {}) ⇒ Struct
Deletes an AppInstance and all associated data asynchronously.
156 |
# File 'sig/client.rbs', line 156
def delete_app_instance: (
|
#delete_app_instance_admin(params = {}) ⇒ Struct
Demotes an AppInstanceAdmin to an AppInstanceUser or
AppInstanceBot. This action does not delete the user.
162 |
# File 'sig/client.rbs', line 162
def delete_app_instance_admin: (
|
#delete_app_instance_bot(params = {}) ⇒ Struct
Deletes an AppInstanceBot.
169 |
# File 'sig/client.rbs', line 169
def delete_app_instance_bot: (
|
#delete_app_instance_user(params = {}) ⇒ Struct
Deletes an AppInstanceUser.
175 |
# File 'sig/client.rbs', line 175
def delete_app_instance_user: (
|
#deregister_app_instance_user_endpoint(params = {}) ⇒ Struct
Deregisters an AppInstanceUserEndpoint.
181 |
# File 'sig/client.rbs', line 181
def deregister_app_instance_user_endpoint: (
|
#describe_app_instance(params = {}) ⇒ Types::DescribeAppInstanceResponse
Returns the full details of an AppInstance.
192 |
# File 'sig/client.rbs', line 192
def describe_app_instance: (
|
#describe_app_instance_admin(params = {}) ⇒ Types::DescribeAppInstanceAdminResponse
Returns the full details of an AppInstanceAdmin.
202 |
# File 'sig/client.rbs', line 202
def describe_app_instance_admin: (
|
#describe_app_instance_bot(params = {}) ⇒ Types::DescribeAppInstanceBotResponse
The AppInstanceBot's information.
213 |
# File 'sig/client.rbs', line 213
def describe_app_instance_bot: (
|
#describe_app_instance_user(params = {}) ⇒ Types::DescribeAppInstanceUserResponse
Returns the full details of an AppInstanceUser.
223 |
# File 'sig/client.rbs', line 223
def describe_app_instance_user: (
|
#describe_app_instance_user_endpoint(params = {}) ⇒ Types::DescribeAppInstanceUserEndpointResponse
Returns the full details of an AppInstanceUserEndpoint.
233 |
# File 'sig/client.rbs', line 233
def describe_app_instance_user_endpoint: (
|
#get_app_instance_retention_settings(params = {}) ⇒ Types::GetAppInstanceRetentionSettingsResponse
Gets the retention settings for an AppInstance.
245 |
# File 'sig/client.rbs', line 245
def get_app_instance_retention_settings: (
|
#list_app_instance_admins(params = {}) ⇒ Types::ListAppInstanceAdminsResponse
Returns a list of the administrators in the AppInstance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
257 |
# File 'sig/client.rbs', line 257
def list_app_instance_admins: (
|
#list_app_instance_bots(params = {}) ⇒ Types::ListAppInstanceBotsResponse
Lists all AppInstanceBots created under a single AppInstance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
271 |
# File 'sig/client.rbs', line 271
def list_app_instance_bots: (
|
#list_app_instance_user_endpoints(params = {}) ⇒ Types::ListAppInstanceUserEndpointsResponse
Lists all the AppInstanceUserEndpoints created under a single
AppInstanceUser.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
284 |
# File 'sig/client.rbs', line 284
def list_app_instance_user_endpoints: (
|
#list_app_instance_users(params = {}) ⇒ Types::ListAppInstanceUsersResponse
List all AppInstanceUsers created under a single AppInstance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
298 |
# File 'sig/client.rbs', line 298
def list_app_instance_users: (
|
#list_app_instances(params = {}) ⇒ Types::ListAppInstancesResponse
Lists all Amazon Chime AppInstances created under a single AWS
account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
311 |
# File 'sig/client.rbs', line 311
def list_app_instances: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags applied to an Amazon Chime SDK identity resource.
322 |
# File 'sig/client.rbs', line 322
def list_tags_for_resource: (
|
#put_app_instance_retention_settings(params = {}) ⇒ Types::PutAppInstanceRetentionSettingsResponse
Sets the amount of time in days that a given AppInstance retains
data.
333 |
# File 'sig/client.rbs', line 333
def put_app_instance_retention_settings: (
|
#put_app_instance_user_expiration_settings(params = {}) ⇒ Types::PutAppInstanceUserExpirationSettingsResponse
Sets the number of days before the AppInstanceUser is automatically
deleted.
AppInstanceUsers within 6 hours
of expiration. Actual deletion times may vary.
Expired AppInstanceUsers that have not yet been deleted appear as
active, and you can update their expiration settings. The system
honors the new settings.
349 |
# File 'sig/client.rbs', line 349
def put_app_instance_user_expiration_settings: (
|
#register_app_instance_user_endpoint(params = {}) ⇒ Types::RegisterAppInstanceUserEndpointResponse
Registers an endpoint under an Amazon Chime AppInstanceUser. The
endpoint receives messages for a user. For push notifications, the
endpoint is a mobile device used to receive mobile push notifications
for a user.
364 |
# File 'sig/client.rbs', line 364
def register_app_instance_user_endpoint: (
|
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified Amazon Chime SDK identity resource.
379 |
# File 'sig/client.rbs', line 379
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified Amazon Chime SDK identity resource.
391 |
# File 'sig/client.rbs', line 391
def untag_resource: (
|
#update_app_instance(params = {}) ⇒ Types::UpdateAppInstanceResponse
Updates AppInstance metadata.
402 |
# File 'sig/client.rbs', line 402
def update_app_instance: (
|
#update_app_instance_bot(params = {}) ⇒ Types::UpdateAppInstanceBotResponse
Updates the name and metadata of an AppInstanceBot.
414 |
# File 'sig/client.rbs', line 414
def update_app_instance_bot: (
|
#update_app_instance_user(params = {}) ⇒ Types::UpdateAppInstanceUserResponse
Updates the details of an AppInstanceUser. You can update names and
metadata.
427 |
# File 'sig/client.rbs', line 427
def update_app_instance_user: (
|
#update_app_instance_user_endpoint(params = {}) ⇒ Types::UpdateAppInstanceUserEndpointResponse
Updates the details of an AppInstanceUserEndpoint. You can update
the name and AllowMessage values.
440 |
# File 'sig/client.rbs', line 440
def update_app_instance_user_endpoint: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1713 1714 1715 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1713 def waiter_names [] end |