Class: Aws::ChimeSDKIdentity::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ChimeSDKIdentity::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-chimesdkidentity/client.rb
Overview
An API client for ChimeSDKIdentity. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ChimeSDKIdentity::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_app_instance(params = {}) ⇒ Types::CreateAppInstanceResponse
Creates an Amazon Chime SDK messaging ‘AppInstance` under an AWS account.
-
#create_app_instance_admin(params = {}) ⇒ Types::CreateAppInstanceAdminResponse
Promotes an ‘AppInstanceUser` or `AppInstanceBot` to an `AppInstanceAdmin`.
-
#create_app_instance_bot(params = {}) ⇒ Types::CreateAppInstanceBotResponse
Creates a bot under an Amazon Chime ‘AppInstance`.
-
#create_app_instance_user(params = {}) ⇒ Types::CreateAppInstanceUserResponse
Creates a user under an Amazon Chime ‘AppInstance`.
-
#delete_app_instance(params = {}) ⇒ Struct
Deletes an ‘AppInstance` and all associated data asynchronously.
-
#delete_app_instance_admin(params = {}) ⇒ Struct
Demotes an ‘AppInstanceAdmin` to an `AppInstanceUser` or `AppInstanceBot`.
-
#delete_app_instance_bot(params = {}) ⇒ Struct
Deletes an ‘AppInstanceBot`.
-
#delete_app_instance_user(params = {}) ⇒ Struct
Deletes an ‘AppInstanceUser`.
-
#deregister_app_instance_user_endpoint(params = {}) ⇒ Struct
Deregisters an ‘AppInstanceUserEndpoint`.
-
#describe_app_instance(params = {}) ⇒ Types::DescribeAppInstanceResponse
Returns the full details of an ‘AppInstance`.
-
#describe_app_instance_admin(params = {}) ⇒ Types::DescribeAppInstanceAdminResponse
Returns the full details of an ‘AppInstanceAdmin`.
-
#describe_app_instance_bot(params = {}) ⇒ Types::DescribeAppInstanceBotResponse
The ‘AppInstanceBot’s` information.
-
#describe_app_instance_user(params = {}) ⇒ Types::DescribeAppInstanceUserResponse
Returns the full details of an ‘AppInstanceUser`.
-
#describe_app_instance_user_endpoint(params = {}) ⇒ Types::DescribeAppInstanceUserEndpointResponse
Returns the full details of an ‘AppInstanceUserEndpoint`.
-
#get_app_instance_retention_settings(params = {}) ⇒ Types::GetAppInstanceRetentionSettingsResponse
Gets the retention settings for an ‘AppInstance`.
-
#list_app_instance_admins(params = {}) ⇒ Types::ListAppInstanceAdminsResponse
Returns a list of the administrators in the ‘AppInstance`.
-
#list_app_instance_bots(params = {}) ⇒ Types::ListAppInstanceBotsResponse
Lists all ‘AppInstanceBots` created under a single `AppInstance`.
-
#list_app_instance_user_endpoints(params = {}) ⇒ Types::ListAppInstanceUserEndpointsResponse
Lists all the ‘AppInstanceUserEndpoints` created under a single `AppInstanceUser`.
-
#list_app_instance_users(params = {}) ⇒ Types::ListAppInstanceUsersResponse
List all ‘AppInstanceUsers` created under a single `AppInstance`.
-
#list_app_instances(params = {}) ⇒ Types::ListAppInstancesResponse
Lists all Amazon Chime ‘AppInstance`s created under a single AWS account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags applied to an Amazon Chime SDK identity resource.
-
#put_app_instance_retention_settings(params = {}) ⇒ Types::PutAppInstanceRetentionSettingsResponse
Sets the amount of time in days that a given ‘AppInstance` retains data.
-
#put_app_instance_user_expiration_settings(params = {}) ⇒ Types::PutAppInstanceUserExpirationSettingsResponse
Sets the number of days before the ‘AppInstanceUser` is automatically deleted.
-
#register_app_instance_user_endpoint(params = {}) ⇒ Types::RegisterAppInstanceUserEndpointResponse
Registers an endpoint under an Amazon Chime ‘AppInstanceUser`.
-
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified Amazon Chime SDK identity resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified Amazon Chime SDK identity resource.
-
#update_app_instance(params = {}) ⇒ Types::UpdateAppInstanceResponse
Updates ‘AppInstance` metadata.
-
#update_app_instance_bot(params = {}) ⇒ Types::UpdateAppInstanceBotResponse
Updates the name and metadata of an ‘AppInstanceBot`.
-
#update_app_instance_user(params = {}) ⇒ Types::UpdateAppInstanceUserResponse
Updates the details of an ‘AppInstanceUser`.
-
#update_app_instance_user_endpoint(params = {}) ⇒ Types::UpdateAppInstanceUserEndpointResponse
Updates the details of an ‘AppInstanceUserEndpoint`.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1720 1721 1722 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1720 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1723 1724 1725 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1723 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1693 1694 1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1693 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ChimeSDKIdentity') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-chimesdkidentity' context[:gem_version] = '1.58.0' Seahorse::Client::Request.new(handlers, context) end |
#create_app_instance(params = {}) ⇒ Types::CreateAppInstanceResponse
Creates an Amazon Chime SDK messaging ‘AppInstance` under an AWS account. Only SDK messaging customers use this API. `CreateAppInstance` supports idempotency behavior as described in the AWS API Standard.
identity
526 527 528 529 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 526 def create_app_instance(params = {}, = {}) req = build_request(:create_app_instance, params) req.send_request() end |
#create_app_instance_admin(params = {}) ⇒ Types::CreateAppInstanceAdminResponse
Promotes an ‘AppInstanceUser` or `AppInstanceBot` to an `AppInstanceAdmin`. The promoted entity can perform the following actions.
-
‘ChannelModerator` actions across all channels in the `AppInstance`.
-
‘DeleteChannelMessage` actions.
Only an ‘AppInstanceUser` and `AppInstanceBot` can be promoted to an `AppInstanceAdmin` role.
570 571 572 573 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 570 def create_app_instance_admin(params = {}, = {}) req = build_request(:create_app_instance_admin, params) req.send_request() end |
#create_app_instance_bot(params = {}) ⇒ Types::CreateAppInstanceBotResponse
Creates a bot under an Amazon Chime ‘AppInstance`. The request consists of a unique `Configuration` and `Name` for that bot.
639 640 641 642 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 639 def create_app_instance_bot(params = {}, = {}) req = build_request(:create_app_instance_bot, params) req.send_request() end |
#create_app_instance_user(params = {}) ⇒ Types::CreateAppInstanceUserResponse
Creates a user under an Amazon Chime ‘AppInstance`. The request consists of a unique `appInstanceUserId` and `Name` for that user.
705 706 707 708 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 705 def create_app_instance_user(params = {}, = {}) req = build_request(:create_app_instance_user, params) req.send_request() end |
#delete_app_instance(params = {}) ⇒ Struct
Deletes an ‘AppInstance` and all associated data asynchronously.
727 728 729 730 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 727 def delete_app_instance(params = {}, = {}) req = build_request(:delete_app_instance, params) req.send_request() end |
#delete_app_instance_admin(params = {}) ⇒ Struct
Demotes an ‘AppInstanceAdmin` to an `AppInstanceUser` or `AppInstanceBot`. This action does not delete the user.
754 755 756 757 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 754 def delete_app_instance_admin(params = {}, = {}) req = build_request(:delete_app_instance_admin, params) req.send_request() end |
#delete_app_instance_bot(params = {}) ⇒ Struct
Deletes an ‘AppInstanceBot`.
776 777 778 779 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 776 def delete_app_instance_bot(params = {}, = {}) req = build_request(:delete_app_instance_bot, params) req.send_request() end |
#delete_app_instance_user(params = {}) ⇒ Struct
Deletes an ‘AppInstanceUser`.
798 799 800 801 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 798 def delete_app_instance_user(params = {}, = {}) req = build_request(:delete_app_instance_user, params) req.send_request() end |
#deregister_app_instance_user_endpoint(params = {}) ⇒ Struct
Deregisters an ‘AppInstanceUserEndpoint`.
824 825 826 827 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 824 def deregister_app_instance_user_endpoint(params = {}, = {}) req = build_request(:deregister_app_instance_user_endpoint, params) req.send_request() end |
#describe_app_instance(params = {}) ⇒ Types::DescribeAppInstanceResponse
Returns the full details of an ‘AppInstance`.
856 857 858 859 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 856 def describe_app_instance(params = {}, = {}) req = build_request(:describe_app_instance, params) req.send_request() end |
#describe_app_instance_admin(params = {}) ⇒ Types::DescribeAppInstanceAdminResponse
Returns the full details of an ‘AppInstanceAdmin`.
891 892 893 894 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 891 def describe_app_instance_admin(params = {}, = {}) req = build_request(:describe_app_instance_admin, params) req.send_request() end |
#describe_app_instance_bot(params = {}) ⇒ Types::DescribeAppInstanceBotResponse
The ‘AppInstanceBot’s` information.
929 930 931 932 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 929 def describe_app_instance_bot(params = {}, = {}) req = build_request(:describe_app_instance_bot, params) req.send_request() end |
#describe_app_instance_user(params = {}) ⇒ Types::DescribeAppInstanceUserResponse
Returns the full details of an ‘AppInstanceUser`.
963 964 965 966 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 963 def describe_app_instance_user(params = {}, = {}) req = build_request(:describe_app_instance_user, params) req.send_request() end |
#describe_app_instance_user_endpoint(params = {}) ⇒ Types::DescribeAppInstanceUserEndpointResponse
Returns the full details of an ‘AppInstanceUserEndpoint`.
1006 1007 1008 1009 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1006 def describe_app_instance_user_endpoint(params = {}, = {}) req = build_request(:describe_app_instance_user_endpoint, params) req.send_request() end |
#get_app_instance_retention_settings(params = {}) ⇒ Types::GetAppInstanceRetentionSettingsResponse
Gets the retention settings for an ‘AppInstance`.
1036 1037 1038 1039 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1036 def get_app_instance_retention_settings(params = {}, = {}) req = build_request(:get_app_instance_retention_settings, params) req.send_request() end |
#list_app_instance_admins(params = {}) ⇒ Types::ListAppInstanceAdminsResponse
Returns a list of the administrators in the ‘AppInstance`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1081 1082 1083 1084 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1081 def list_app_instance_admins(params = {}, = {}) req = build_request(:list_app_instance_admins, params) req.send_request() end |
#list_app_instance_bots(params = {}) ⇒ Types::ListAppInstanceBotsResponse
Lists all ‘AppInstanceBots` created under a single `AppInstance`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1127 1128 1129 1130 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1127 def list_app_instance_bots(params = {}, = {}) req = build_request(:list_app_instance_bots, params) req.send_request() end |
#list_app_instance_user_endpoints(params = {}) ⇒ Types::ListAppInstanceUserEndpointsResponse
Lists all the ‘AppInstanceUserEndpoints` created under a single `AppInstanceUser`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1176 1177 1178 1179 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1176 def list_app_instance_user_endpoints(params = {}, = {}) req = build_request(:list_app_instance_user_endpoints, params) req.send_request() end |
#list_app_instance_users(params = {}) ⇒ Types::ListAppInstanceUsersResponse
List all ‘AppInstanceUsers` created under a single `AppInstance`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1222 1223 1224 1225 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1222 def list_app_instance_users(params = {}, = {}) req = build_request(:list_app_instance_users, params) req.send_request() end |
#list_app_instances(params = {}) ⇒ Types::ListAppInstancesResponse
Lists all Amazon Chime ‘AppInstance`s created under a single AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1263 1264 1265 1266 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1263 def list_app_instances(params = {}, = {}) req = build_request(:list_app_instances, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags applied to an Amazon Chime SDK identity resource.
1293 1294 1295 1296 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1293 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_app_instance_retention_settings(params = {}) ⇒ Types::PutAppInstanceRetentionSettingsResponse
Sets the amount of time in days that a given ‘AppInstance` retains data.
1332 1333 1334 1335 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1332 def put_app_instance_retention_settings(params = {}, = {}) req = build_request(:put_app_instance_retention_settings, params) req.send_request() end |
#put_app_instance_user_expiration_settings(params = {}) ⇒ Types::PutAppInstanceUserExpirationSettingsResponse
Sets the number of days before the ‘AppInstanceUser` is automatically deleted.
<note markdown=“1”> A background process deletes expired ‘AppInstanceUsers` within 6 hours of expiration. Actual deletion times may vary.
Expired `AppInstanceUsers` that have not yet been deleted appear as
active, and you can update their expiration settings. The system honors the new settings.
</note>
1381 1382 1383 1384 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1381 def put_app_instance_user_expiration_settings(params = {}, = {}) req = build_request(:put_app_instance_user_expiration_settings, params) req.send_request() end |
#register_app_instance_user_endpoint(params = {}) ⇒ Types::RegisterAppInstanceUserEndpointResponse
Registers an endpoint under an Amazon Chime ‘AppInstanceUser`. The endpoint receives messages for a user. For push notifications, the endpoint is a mobile device used to receive mobile push notifications for a user.
1456 1457 1458 1459 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1456 def register_app_instance_user_endpoint(params = {}, = {}) req = build_request(:register_app_instance_user_endpoint, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified Amazon Chime SDK identity resource.
1488 1489 1490 1491 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1488 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified Amazon Chime SDK identity resource.
1515 1516 1517 1518 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1515 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_app_instance(params = {}) ⇒ Types::UpdateAppInstanceResponse
Updates ‘AppInstance` metadata.
1551 1552 1553 1554 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1551 def update_app_instance(params = {}, = {}) req = build_request(:update_app_instance, params) req.send_request() end |
#update_app_instance_bot(params = {}) ⇒ Types::UpdateAppInstanceBotResponse
Updates the name and metadata of an ‘AppInstanceBot`.
1602 1603 1604 1605 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1602 def update_app_instance_bot(params = {}, = {}) req = build_request(:update_app_instance_bot, params) req.send_request() end |
#update_app_instance_user(params = {}) ⇒ Types::UpdateAppInstanceUserResponse
Updates the details of an ‘AppInstanceUser`. You can update names and metadata.
1639 1640 1641 1642 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1639 def update_app_instance_user(params = {}, = {}) req = build_request(:update_app_instance_user, params) req.send_request() end |
#update_app_instance_user_endpoint(params = {}) ⇒ Types::UpdateAppInstanceUserEndpointResponse
Updates the details of an ‘AppInstanceUserEndpoint`. You can update the name and `AllowMessage` values.
1684 1685 1686 1687 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1684 def update_app_instance_user_endpoint(params = {}, = {}) req = build_request(:update_app_instance_user_endpoint, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1713 1714 1715 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1713 def waiter_names [] end |