Class: Aws::ChimeSDKIdentity::Client

Inherits:
Seahorse::Client::Base
  • Object
show all
Includes:
Aws::ClientStubs
Defined in:
lib/aws-sdk-chimesdkidentity/client.rb

Overview

An API client for ChimeSDKIdentity. To construct a client, you need to configure a ‘:region` and `:credentials`.

client = Aws::ChimeSDKIdentity::Client.new(
  region: region_name,
  credentials: credentials,
  # ...
)

For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).

See #initialize for a full list of supported configuration options.

Class Attribute Summary collapse

API Operations collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ Client

Returns a new instance of Client.

Parameters:

  • options (Hash)

Options Hash (options):

  • :plugins (Array<Seahorse::Client::Plugin>) — default: []]

    A list of plugins to apply to the client. Each plugin is either a class name or an instance of a plugin class.

  • :credentials (required, Aws::CredentialProvider)

    Your AWS credentials used for authentication. This can be any class that includes and implements ‘Aws::CredentialProvider`, or instance of any one of the following classes:

    • ‘Aws::Credentials` - Used for configuring static, non-refreshing credentials.

    • ‘Aws::SharedCredentials` - Used for loading static credentials from a shared file, such as `~/.aws/config`.

    • ‘Aws::AssumeRoleCredentials` - Used when you need to assume a role.

    • ‘Aws::AssumeRoleWebIdentityCredentials` - Used when you need to assume a role after providing credentials via the web.

    • ‘Aws::SSOCredentials` - Used for loading credentials from AWS SSO using an access token generated from `aws login`.

    • ‘Aws::ProcessCredentials` - Used for loading credentials from a process that outputs to stdout.

    • ‘Aws::InstanceProfileCredentials` - Used for loading credentials from an EC2 IMDS on an EC2 instance.

    • ‘Aws::ECSCredentials` - Used for loading credentials from instances running in ECS.

    • ‘Aws::CognitoIdentityCredentials` - Used for loading credentials from the Cognito Identity service.

    When ‘:credentials` are not configured directly, the following locations will be searched for credentials:

    • Aws.config`

    • The ‘:access_key_id`, `:secret_access_key`, `:session_token`, and `:account_id` options.

    • ENV`, `ENV`, `ENV`, and `ENV`.

    • ‘~/.aws/credentials`

    • ‘~/.aws/config`

    • EC2/ECS IMDS instance profile - When used by default, the timeouts are very aggressive. Construct and pass an instance of ‘Aws::InstanceProfileCredentials` or `Aws::ECSCredentials` to enable retries and extended timeouts. Instance profile credential fetching can be disabled by setting `ENV` to `true`.

  • :region (required, String)

    The AWS region to connect to. The configured ‘:region` is used to determine the service `:endpoint`. When not passed, a default `:region` is searched for in the following locations:

  • :access_key_id (String)
  • :account_id (String)
  • :active_endpoint_cache (Boolean) — default: false

    When set to ‘true`, a thread polling for endpoints will be running in the background every 60 secs (default). Defaults to `false`.

  • :adaptive_retry_wait_to_fill (Boolean) — default: true

    Used only in ‘adaptive` retry mode. When true, the request will sleep until there is sufficent client side capacity to retry the request. When false, the request will raise a `RetryCapacityNotAvailableError` and will not retry instead of sleeping.

  • :auth_scheme_preference (Array<String>)

    A list of preferred authentication schemes to use when making a request. Supported values are: ‘sigv4`, `sigv4a`, `httpBearerAuth`, and `noAuth`. When set using `ENV` or in shared config as `auth_scheme_preference`, the value should be a comma-separated list.

  • :client_side_monitoring (Boolean) — default: false

    When ‘true`, client-side metrics will be collected for all API requests from this client.

  • :client_side_monitoring_client_id (String) — default: ""

    Allows you to provide an identifier for this client which will be attached to all generated client side metrics. Defaults to an empty string.

  • :client_side_monitoring_host (String) — default: "127.0.0.1"

    Allows you to specify the DNS hostname or IPv4 or IPv6 address that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_port (Integer) — default: 31000

    Required for publishing client metrics. The port that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_publisher (Aws::ClientSideMonitoring::Publisher) — default: Aws::ClientSideMonitoring::Publisher

    Allows you to provide a custom client-side monitoring publisher class. By default, will use the Client Side Monitoring Agent Publisher.

  • :convert_params (Boolean) — default: true

    When ‘true`, an attempt is made to coerce request parameters into the required types.

  • :correct_clock_skew (Boolean) — default: true

    Used only in ‘standard` and adaptive retry modes. Specifies whether to apply a clock skew correction and retry requests with skewed client clocks.

  • :defaults_mode (String) — default: "legacy"

    See DefaultsModeConfiguration for a list of the accepted modes and the configuration defaults that are included.

  • :disable_host_prefix_injection (Boolean) — default: false

    When ‘true`, the SDK will not prepend the modeled host prefix to the endpoint.

  • :disable_request_compression (Boolean) — default: false

    When set to ‘true’ the request body will not be compressed for supported operations.

  • :endpoint (String, URI::HTTPS, URI::HTTP)

    Normally you should not configure the ‘:endpoint` option directly. This is normally constructed from the `:region` option. Configuring `:endpoint` is normally reserved for connecting to test or custom endpoints. The endpoint should be a URI formatted like:

    'http://example.com'
    'https://example.com'
    'http://example.com:123'
    
  • :endpoint_cache_max_entries (Integer) — default: 1000

    Used for the maximum size limit of the LRU cache storing endpoints data for endpoint discovery enabled operations. Defaults to 1000.

  • :endpoint_cache_max_threads (Integer) — default: 10

    Used for the maximum threads in use for polling endpoints to be cached, defaults to 10.

  • :endpoint_cache_poll_interval (Integer) — default: 60

    When :endpoint_discovery and :active_endpoint_cache is enabled, Use this option to config the time interval in seconds for making requests fetching endpoints information. Defaults to 60 sec.

  • :endpoint_discovery (Boolean) — default: false

    When set to ‘true`, endpoint discovery will be enabled for operations when available.

  • :ignore_configured_endpoint_urls (Boolean)

    Setting to true disables use of endpoint URLs provided via environment variables and the shared configuration file.

  • :log_formatter (Aws::Log::Formatter) — default: Aws::Log::Formatter.default

    The log formatter.

  • :log_level (Symbol) — default: :info

    The log level to send messages to the ‘:logger` at.

  • :logger (Logger)

    The Logger instance to send log messages to. If this option is not set, logging will be disabled.

  • :max_attempts (Integer) — default: 3

    An integer representing the maximum number attempts that will be made for a single request, including the initial attempt. For example, setting this value to 5 will result in a request being retried up to 4 times. Used in ‘standard` and `adaptive` retry modes.

  • :profile (String) — default: "default"

    Used when loading credentials from the shared credentials file at ‘HOME/.aws/credentials`. When not specified, ’default’ is used.

  • :request_checksum_calculation (String) — default: "when_supported"

    Determines when a checksum will be calculated for request payloads. Values are:

    • ‘when_supported` - (default) When set, a checksum will be calculated for all request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` and/or a `requestAlgorithmMember` is modeled.

    • ‘when_required` - When set, a checksum will only be calculated for request payloads of operations modeled with the `httpChecksum` trait where `requestChecksumRequired` is `true` or where a `requestAlgorithmMember` is modeled and supplied.

  • :request_min_compression_size_bytes (Integer) — default: 10240

    The minimum size in bytes that triggers compression for request bodies. The value must be non-negative integer value between 0 and 10485780 bytes inclusive.

  • :response_checksum_validation (String) — default: "when_supported"

    Determines when checksum validation will be performed on response payloads. Values are:

    • ‘when_supported` - (default) When set, checksum validation is performed on all response payloads of operations modeled with the `httpChecksum` trait where `responseAlgorithms` is modeled, except when no modeled checksum algorithms are supported.

    • ‘when_required` - When set, checksum validation is not performed on response payloads of operations unless the checksum algorithm is supported and the `requestValidationModeMember` member is set to `ENABLED`.

  • :retry_backoff (Proc)

    A proc or lambda used for backoff. Defaults to 2**retries * retry_base_delay. This option is only used in the ‘legacy` retry mode.

  • :retry_base_delay (Float) — default: 0.3

    The base delay in seconds used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_jitter (Symbol) — default: :none

    A delay randomiser function used by the default backoff function. Some predefined functions can be referenced by name - :none, :equal, :full, otherwise a Proc that takes and returns a number. This option is only used in the ‘legacy` retry mode.

    @see www.awsarchitectureblog.com/2015/03/backoff.html

  • :retry_limit (Integer) — default: 3

    The maximum number of times to retry failed requests. Only ~ 500 level server errors and certain ~ 400 level client errors are retried. Generally, these are throttling errors, data checksum errors, networking errors, timeout errors, auth errors, endpoint discovery, and errors from expired credentials. This option is only used in the ‘legacy` retry mode.

  • :retry_max_delay (Integer) — default: 0

    The maximum number of seconds to delay between retries (0 for no limit) used by the default backoff function. This option is only used in the ‘legacy` retry mode.

  • :retry_mode (String) — default: "legacy"

    Specifies which retry algorithm to use. Values are:

    • ‘legacy` - The pre-existing retry behavior. This is default value if no retry mode is provided.

    • ‘standard` - A standardized set of retry rules across the AWS SDKs. This includes support for retry quotas, which limit the number of unsuccessful retries a client can make.

    • ‘adaptive` - An experimental retry mode that includes all the functionality of `standard` mode along with automatic client side throttling. This is a provisional mode that may change behavior in the future.

  • :sdk_ua_app_id (String)

    A unique and opaque application ID that is appended to the User-Agent header as app/sdk_ua_app_id. It should have a maximum length of 50. This variable is sourced from environment variable AWS_SDK_UA_APP_ID or the shared config profile attribute sdk_ua_app_id.

  • :secret_access_key (String)
  • :session_token (String)
  • :sigv4a_signing_region_set (Array)

    A list of regions that should be signed with SigV4a signing. When not passed, a default ‘:sigv4a_signing_region_set` is searched for in the following locations:

  • :stub_responses (Boolean) — default: false

    Causes the client to return stubbed responses. By default fake responses are generated and returned. You can specify the response data to return or errors to raise by calling ClientStubs#stub_responses. See ClientStubs for more information.

    ** Please note ** When response stubbing is enabled, no HTTP requests are made, and retries are disabled.

  • :telemetry_provider (Aws::Telemetry::TelemetryProviderBase) — default: Aws::Telemetry::NoOpTelemetryProvider

    Allows you to provide a telemetry provider, which is used to emit telemetry data. By default, uses ‘NoOpTelemetryProvider` which will not record or emit any telemetry data. The SDK supports the following telemetry providers:

    • OpenTelemetry (OTel) - To use the OTel provider, install and require the

    ‘opentelemetry-sdk` gem and then, pass in an instance of a `Aws::Telemetry::OTelProvider` for telemetry provider.

  • :token_provider (Aws::TokenProvider)

    Your Bearer token used for authentication. This can be any class that includes and implements ‘Aws::TokenProvider`, or instance of any one of the following classes:

    • ‘Aws::StaticTokenProvider` - Used for configuring static, non-refreshing tokens.

    • ‘Aws::SSOTokenProvider` - Used for loading tokens from AWS SSO using an access token generated from `aws login`.

    When ‘:token_provider` is not configured directly, the `Aws::TokenProviderChain` will be used to search for tokens configured for your profile in shared configuration files.

  • :use_dualstack_endpoint (Boolean)

    When set to ‘true`, dualstack enabled endpoints (with `.aws` TLD) will be used if available.

  • :use_fips_endpoint (Boolean)

    When set to ‘true`, fips compatible endpoints will be used if available. When a `fips` region is used, the region is normalized and this config is set to `true`.

  • :validate_params (Boolean) — default: true

    When ‘true`, request parameters are validated before sending the request.

  • :endpoint_provider (Aws::ChimeSDKIdentity::EndpointProvider)

    The endpoint provider used to resolve endpoints. Any object that responds to ‘#resolve_endpoint(parameters)` where `parameters` is a Struct similar to `Aws::ChimeSDKIdentity::EndpointParameters`.

  • :http_continue_timeout (Float) — default: 1

    The number of seconds to wait for a 100-continue response before sending the request body. This option has no effect unless the request has “Expect” header set to “100-continue”. Defaults to ‘nil` which disables this behaviour. This value can safely be set per request on the session.

  • :http_idle_timeout (Float) — default: 5

    The number of seconds a connection is allowed to sit idle before it is considered stale. Stale connections are closed and removed from the pool before making a request.

  • :http_open_timeout (Float) — default: 15

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_proxy (URI::HTTP, String)

    A proxy to send requests through. Formatted like ‘proxy.com:123’.

  • :http_read_timeout (Float) — default: 60

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_wire_trace (Boolean) — default: false

    When ‘true`, HTTP debug output will be sent to the `:logger`.

  • :on_chunk_received (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the response body is received. It provides three arguments: the chunk, the number of bytes received, and the total number of bytes in the response (or nil if the server did not send a ‘content-length`).

  • :on_chunk_sent (Proc)

    When a Proc object is provided, it will be used as callback when each chunk of the request body is sent. It provides three arguments: the chunk, the number of bytes read from the body, and the total number of bytes in the body.

  • :raise_response_errors (Boolean) — default: true

    When ‘true`, response errors are raised.

  • :ssl_ca_bundle (String)

    Full path to the SSL certificate authority bundle file that should be used when verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_directory (String)

    Full path of the directory that contains the unbundled SSL certificate authority files for verifying peer certificates. If you do not pass ‘:ssl_ca_bundle` or `:ssl_ca_directory` the the system default will be used if available.

  • :ssl_ca_store (String)

    Sets the X509::Store to verify peer certificate.

  • :ssl_cert (OpenSSL::X509::Certificate)

    Sets a client certificate when creating http connections.

  • :ssl_key (OpenSSL::PKey)

    Sets a client key when creating http connections.

  • :ssl_timeout (Float)

    Sets the SSL timeout in seconds

  • :ssl_verify_peer (Boolean) — default: true

    When ‘true`, SSL peer certificates are verified when establishing a connection.



473
474
475
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 473

def initialize(*args)
  super
end

Class Attribute Details

.identifierObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1722
1723
1724
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1722

def identifier
  @identifier
end

Class Method Details

.errors_moduleObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1725
1726
1727
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1725

def errors_module
  Errors
end

Instance Method Details

#build_request(operation_name, params = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • params ({}) (defaults to: {})


1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1695

def build_request(operation_name, params = {})
  handlers = @handlers.for(operation_name)
  tracer = config.telemetry_provider.tracer_provider.tracer(
    Aws::Telemetry.module_to_tracer_name('Aws::ChimeSDKIdentity')
  )
  context = Seahorse::Client::RequestContext.new(
    operation_name: operation_name,
    operation: config.api.operation(operation_name),
    client: self,
    params: params,
    config: config,
    tracer: tracer
  )
  context[:gem_name] = 'aws-sdk-chimesdkidentity'
  context[:gem_version] = '1.53.0'
  Seahorse::Client::Request.new(handlers, context)
end

#create_app_instance(params = {}) ⇒ Types::CreateAppInstanceResponse

Creates an Amazon Chime SDK messaging ‘AppInstance` under an AWS account. Only SDK messaging customers use this API. `CreateAppInstance` supports idempotency behavior as described in the AWS API Standard.

identity

Examples:

Request syntax with placeholder values


resp = client.create_app_instance({
  name: "NonEmptyResourceName", # required
  metadata: "Metadata",
  client_request_token: "ClientRequestToken", # required
  tags: [
    {
      key: "TagKey", # required
      value: "TagValue", # required
    },
  ],
})

Response structure


resp.app_instance_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :name (required, String)

    The name of the ‘AppInstance`.

  • :metadata (String)

    The metadata of the ‘AppInstance`. Limited to a 1KB string in UTF-8.

  • :client_request_token (required, String)

    The unique ID of the request. Use different tokens to create different ‘AppInstances`.

    **A suitable default value is auto-generated.** You should normally not need to pass this option.**

  • :tags (Array<Types::Tag>)

    Tags assigned to the ‘AppInstance`.

Returns:

See Also:



528
529
530
531
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 528

def create_app_instance(params = {}, options = {})
  req = build_request(:create_app_instance, params)
  req.send_request(options)
end

#create_app_instance_admin(params = {}) ⇒ Types::CreateAppInstanceAdminResponse

Promotes an ‘AppInstanceUser` or `AppInstanceBot` to an `AppInstanceAdmin`. The promoted entity can perform the following actions.

  • ‘ChannelModerator` actions across all channels in the `AppInstance`.

  • ‘DeleteChannelMessage` actions.

Only an ‘AppInstanceUser` and `AppInstanceBot` can be promoted to an `AppInstanceAdmin` role.

Examples:

Request syntax with placeholder values


resp = client.create_app_instance_admin({
  app_instance_admin_arn: "ChimeArn", # required
  app_instance_arn: "ChimeArn", # required
})

Response structure


resp.app_instance_admin.arn #=> String
resp.app_instance_admin.name #=> String
resp.app_instance_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_admin_arn (required, String)

    The ARN of the administrator of the current ‘AppInstance`.

  • :app_instance_arn (required, String)

    The ARN of the ‘AppInstance`.

Returns:

See Also:



572
573
574
575
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 572

def create_app_instance_admin(params = {}, options = {})
  req = build_request(:create_app_instance_admin, params)
  req.send_request(options)
end

#create_app_instance_bot(params = {}) ⇒ Types::CreateAppInstanceBotResponse

Creates a bot under an Amazon Chime ‘AppInstance`. The request consists of a unique `Configuration` and `Name` for that bot.

Examples:

Request syntax with placeholder values


resp = client.create_app_instance_bot({
  app_instance_arn: "ChimeArn", # required
  name: "ResourceName",
  metadata: "Metadata",
  client_request_token: "ClientRequestToken", # required
  tags: [
    {
      key: "TagKey", # required
      value: "TagValue", # required
    },
  ],
  configuration: { # required
    lex: { # required
      responds_to: "STANDARD_MESSAGES", # accepts STANDARD_MESSAGES
      invoked_by: {
        standard_messages: "AUTO", # required, accepts AUTO, ALL, MENTIONS, NONE
        targeted_messages: "ALL", # required, accepts ALL, NONE
      },
      lex_bot_alias_arn: "LexBotAliasArn", # required
      locale_id: "String", # required
      welcome_intent: "LexIntentName",
    },
  },
})

Response structure


resp.app_instance_bot_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_arn (required, String)

    The ARN of the ‘AppInstance` request.

  • :name (String)

    The user’s name.

  • :metadata (String)

    The request metadata. Limited to a 1KB string in UTF-8.

  • :client_request_token (required, String)

    The unique ID for the client making the request. Use different tokens for different ‘AppInstanceBots`.

    **A suitable default value is auto-generated.** You should normally not need to pass this option.**

  • :tags (Array<Types::Tag>)

    The tags assigned to the ‘AppInstanceBot`.

  • :configuration (required, Types::Configuration)

    Configuration information about the Amazon Lex V2 V2 bot.

Returns:

See Also:



641
642
643
644
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 641

def create_app_instance_bot(params = {}, options = {})
  req = build_request(:create_app_instance_bot, params)
  req.send_request(options)
end

#create_app_instance_user(params = {}) ⇒ Types::CreateAppInstanceUserResponse

Creates a user under an Amazon Chime ‘AppInstance`. The request consists of a unique `appInstanceUserId` and `Name` for that user.

Examples:

Request syntax with placeholder values


resp = client.create_app_instance_user({
  app_instance_arn: "ChimeArn", # required
  app_instance_user_id: "UserId", # required
  name: "UserName", # required
  metadata: "Metadata",
  client_request_token: "ClientRequestToken", # required
  tags: [
    {
      key: "TagKey", # required
      value: "TagValue", # required
    },
  ],
  expiration_settings: {
    expiration_days: 1, # required
    expiration_criterion: "CREATED_TIMESTAMP", # required, accepts CREATED_TIMESTAMP
  },
})

Response structure


resp.app_instance_user_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_arn (required, String)

    The ARN of the ‘AppInstance` request.

  • :app_instance_user_id (required, String)

    The user ID of the ‘AppInstance`.

  • :name (required, String)

    The user’s name.

  • :metadata (String)

    The request’s metadata. Limited to a 1KB string in UTF-8.

  • :client_request_token (required, String)

    The unique ID of the request. Use different tokens to request additional ‘AppInstances`.

    **A suitable default value is auto-generated.** You should normally not need to pass this option.**

  • :tags (Array<Types::Tag>)

    Tags assigned to the ‘AppInstanceUser`.

  • :expiration_settings (Types::ExpirationSettings)

    Settings that control the interval after which the ‘AppInstanceUser` is automatically deleted.

Returns:

See Also:



707
708
709
710
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 707

def create_app_instance_user(params = {}, options = {})
  req = build_request(:create_app_instance_user, params)
  req.send_request(options)
end

#delete_app_instance(params = {}) ⇒ Struct

Deletes an ‘AppInstance` and all associated data asynchronously.

Examples:

Request syntax with placeholder values


resp = client.delete_app_instance({
  app_instance_arn: "ChimeArn", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_arn (required, String)

    The ARN of the ‘AppInstance`.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



729
730
731
732
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 729

def delete_app_instance(params = {}, options = {})
  req = build_request(:delete_app_instance, params)
  req.send_request(options)
end

#delete_app_instance_admin(params = {}) ⇒ Struct

Demotes an ‘AppInstanceAdmin` to an `AppInstanceUser` or `AppInstanceBot`. This action does not delete the user.

Examples:

Request syntax with placeholder values


resp = client.delete_app_instance_admin({
  app_instance_admin_arn: "ChimeArn", # required
  app_instance_arn: "ChimeArn", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_admin_arn (required, String)

    The ARN of the ‘AppInstance`’s administrator.

  • :app_instance_arn (required, String)

    The ARN of the ‘AppInstance`.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



756
757
758
759
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 756

def delete_app_instance_admin(params = {}, options = {})
  req = build_request(:delete_app_instance_admin, params)
  req.send_request(options)
end

#delete_app_instance_bot(params = {}) ⇒ Struct

Deletes an ‘AppInstanceBot`.

Examples:

Request syntax with placeholder values


resp = client.delete_app_instance_bot({
  app_instance_bot_arn: "ChimeArn", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_bot_arn (required, String)

    The ARN of the ‘AppInstanceBot` being deleted.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



778
779
780
781
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 778

def delete_app_instance_bot(params = {}, options = {})
  req = build_request(:delete_app_instance_bot, params)
  req.send_request(options)
end

#delete_app_instance_user(params = {}) ⇒ Struct

Deletes an ‘AppInstanceUser`.

Examples:

Request syntax with placeholder values


resp = client.delete_app_instance_user({
  app_instance_user_arn: "ChimeArn", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_user_arn (required, String)

    The ARN of the user request being deleted.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



800
801
802
803
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 800

def delete_app_instance_user(params = {}, options = {})
  req = build_request(:delete_app_instance_user, params)
  req.send_request(options)
end

#deregister_app_instance_user_endpoint(params = {}) ⇒ Struct

Deregisters an ‘AppInstanceUserEndpoint`.

Examples:

Request syntax with placeholder values


resp = client.deregister_app_instance_user_endpoint({
  app_instance_user_arn: "ChimeArn", # required
  endpoint_id: "String64", # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_user_arn (required, String)

    The ARN of the ‘AppInstanceUser`.

  • :endpoint_id (required, String)

    The unique identifier of the ‘AppInstanceUserEndpoint`.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



826
827
828
829
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 826

def deregister_app_instance_user_endpoint(params = {}, options = {})
  req = build_request(:deregister_app_instance_user_endpoint, params)
  req.send_request(options)
end

#describe_app_instance(params = {}) ⇒ Types::DescribeAppInstanceResponse

Returns the full details of an ‘AppInstance`.

Examples:

Request syntax with placeholder values


resp = client.describe_app_instance({
  app_instance_arn: "ChimeArn", # required
})

Response structure


resp.app_instance.app_instance_arn #=> String
resp.app_instance.name #=> String
resp.app_instance.created_timestamp #=> Time
resp.app_instance.last_updated_timestamp #=> Time
resp.app_instance. #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_arn (required, String)

    The ARN of the ‘AppInstance`.

Returns:

See Also:



858
859
860
861
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 858

def describe_app_instance(params = {}, options = {})
  req = build_request(:describe_app_instance, params)
  req.send_request(options)
end

#describe_app_instance_admin(params = {}) ⇒ Types::DescribeAppInstanceAdminResponse

Returns the full details of an ‘AppInstanceAdmin`.

Examples:

Request syntax with placeholder values


resp = client.describe_app_instance_admin({
  app_instance_admin_arn: "ChimeArn", # required
  app_instance_arn: "ChimeArn", # required
})

Response structure


resp.app_instance_admin.admin.arn #=> String
resp.app_instance_admin.admin.name #=> String
resp.app_instance_admin.app_instance_arn #=> String
resp.app_instance_admin.created_timestamp #=> Time

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_admin_arn (required, String)

    The ARN of the ‘AppInstanceAdmin`.

  • :app_instance_arn (required, String)

    The ARN of the ‘AppInstance`.

Returns:

See Also:



893
894
895
896
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 893

def describe_app_instance_admin(params = {}, options = {})
  req = build_request(:describe_app_instance_admin, params)
  req.send_request(options)
end

#describe_app_instance_bot(params = {}) ⇒ Types::DescribeAppInstanceBotResponse

The ‘AppInstanceBot’s` information.

Examples:

Request syntax with placeholder values


resp = client.describe_app_instance_bot({
  app_instance_bot_arn: "ChimeArn", # required
})

Response structure


resp.app_instance_bot.app_instance_bot_arn #=> String
resp.app_instance_bot.name #=> String
resp.app_instance_bot.configuration.lex.responds_to #=> String, one of "STANDARD_MESSAGES"
resp.app_instance_bot.configuration.lex.invoked_by.standard_messages #=> String, one of "AUTO", "ALL", "MENTIONS", "NONE"
resp.app_instance_bot.configuration.lex.invoked_by.targeted_messages #=> String, one of "ALL", "NONE"
resp.app_instance_bot.configuration.lex.lex_bot_alias_arn #=> String
resp.app_instance_bot.configuration.lex.locale_id #=> String
resp.app_instance_bot.configuration.lex.welcome_intent #=> String
resp.app_instance_bot.created_timestamp #=> Time
resp.app_instance_bot.last_updated_timestamp #=> Time
resp.app_instance_bot. #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_bot_arn (required, String)

    The ARN of the ‘AppInstanceBot`.

Returns:

See Also:



931
932
933
934
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 931

def describe_app_instance_bot(params = {}, options = {})
  req = build_request(:describe_app_instance_bot, params)
  req.send_request(options)
end

#describe_app_instance_user(params = {}) ⇒ Types::DescribeAppInstanceUserResponse

Returns the full details of an ‘AppInstanceUser`.

Examples:

Request syntax with placeholder values


resp = client.describe_app_instance_user({
  app_instance_user_arn: "ChimeArn", # required
})

Response structure


resp.app_instance_user.app_instance_user_arn #=> String
resp.app_instance_user.name #=> String
resp.app_instance_user. #=> String
resp.app_instance_user.created_timestamp #=> Time
resp.app_instance_user.last_updated_timestamp #=> Time
resp.app_instance_user.expiration_settings.expiration_days #=> Integer
resp.app_instance_user.expiration_settings.expiration_criterion #=> String, one of "CREATED_TIMESTAMP"

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_user_arn (required, String)

    The ARN of the ‘AppInstanceUser`.

Returns:

See Also:



965
966
967
968
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 965

def describe_app_instance_user(params = {}, options = {})
  req = build_request(:describe_app_instance_user, params)
  req.send_request(options)
end

#describe_app_instance_user_endpoint(params = {}) ⇒ Types::DescribeAppInstanceUserEndpointResponse

Returns the full details of an ‘AppInstanceUserEndpoint`.

Examples:

Request syntax with placeholder values


resp = client.describe_app_instance_user_endpoint({
  app_instance_user_arn: "String1600", # required
  endpoint_id: "String64", # required
})

Response structure


resp.app_instance_user_endpoint.app_instance_user_arn #=> String
resp.app_instance_user_endpoint.endpoint_id #=> String
resp.app_instance_user_endpoint.name #=> String
resp.app_instance_user_endpoint.type #=> String, one of "APNS", "APNS_SANDBOX", "GCM"
resp.app_instance_user_endpoint.resource_arn #=> String
resp.app_instance_user_endpoint.endpoint_attributes.device_token #=> String
resp.app_instance_user_endpoint.endpoint_attributes.voip_device_token #=> String
resp.app_instance_user_endpoint.created_timestamp #=> Time
resp.app_instance_user_endpoint.last_updated_timestamp #=> Time
resp.app_instance_user_endpoint.allow_messages #=> String, one of "ALL", "NONE"
resp.app_instance_user_endpoint.endpoint_state.status #=> String, one of "ACTIVE", "INACTIVE"
resp.app_instance_user_endpoint.endpoint_state.status_reason #=> String, one of "INVALID_DEVICE_TOKEN", "INVALID_PINPOINT_ARN"

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_user_arn (required, String)

    The ARN of the ‘AppInstanceUser`.

  • :endpoint_id (required, String)

    The unique identifier of the ‘AppInstanceUserEndpoint`.

Returns:

See Also:



1008
1009
1010
1011
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1008

def describe_app_instance_user_endpoint(params = {}, options = {})
  req = build_request(:describe_app_instance_user_endpoint, params)
  req.send_request(options)
end

#get_app_instance_retention_settings(params = {}) ⇒ Types::GetAppInstanceRetentionSettingsResponse

Gets the retention settings for an ‘AppInstance`.

Examples:

Request syntax with placeholder values


resp = client.get_app_instance_retention_settings({
  app_instance_arn: "ChimeArn", # required
})

Response structure


resp.app_instance_retention_settings.channel_retention_settings.retention_days #=> Integer
resp.initiate_deletion_timestamp #=> Time

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_arn (required, String)

    The ARN of the ‘AppInstance`.

Returns:

See Also:



1038
1039
1040
1041
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1038

def get_app_instance_retention_settings(params = {}, options = {})
  req = build_request(:get_app_instance_retention_settings, params)
  req.send_request(options)
end

#list_app_instance_admins(params = {}) ⇒ Types::ListAppInstanceAdminsResponse

Returns a list of the administrators in the ‘AppInstance`.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_app_instance_admins({
  app_instance_arn: "ChimeArn", # required
  max_results: 1,
  next_token: "NextToken",
})

Response structure


resp.app_instance_arn #=> String
resp.app_instance_admins #=> Array
resp.app_instance_admins[0].admin.arn #=> String
resp.app_instance_admins[0].admin.name #=> String
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_arn (required, String)

    The ARN of the ‘AppInstance`.

  • :max_results (Integer)

    The maximum number of administrators that you want to return.

  • :next_token (String)

    The token returned from previous API requests until the number of administrators is reached.

Returns:

See Also:



1083
1084
1085
1086
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1083

def list_app_instance_admins(params = {}, options = {})
  req = build_request(:list_app_instance_admins, params)
  req.send_request(options)
end

#list_app_instance_bots(params = {}) ⇒ Types::ListAppInstanceBotsResponse

Lists all ‘AppInstanceBots` created under a single `AppInstance`.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_app_instance_bots({
  app_instance_arn: "ChimeArn", # required
  max_results: 1,
  next_token: "NextToken",
})

Response structure


resp.app_instance_arn #=> String
resp.app_instance_bots #=> Array
resp.app_instance_bots[0].app_instance_bot_arn #=> String
resp.app_instance_bots[0].name #=> String
resp.app_instance_bots[0]. #=> String
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_arn (required, String)

    The ARN of the ‘AppInstance`.

  • :max_results (Integer)

    The maximum number of requests to return.

  • :next_token (String)

    The token passed by previous API calls until all requested bots are returned.

Returns:

See Also:



1129
1130
1131
1132
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1129

def list_app_instance_bots(params = {}, options = {})
  req = build_request(:list_app_instance_bots, params)
  req.send_request(options)
end

#list_app_instance_user_endpoints(params = {}) ⇒ Types::ListAppInstanceUserEndpointsResponse

Lists all the ‘AppInstanceUserEndpoints` created under a single `AppInstanceUser`.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_app_instance_user_endpoints({
  app_instance_user_arn: "SensitiveChimeArn", # required
  max_results: 1,
  next_token: "NextToken",
})

Response structure


resp.app_instance_user_endpoints #=> Array
resp.app_instance_user_endpoints[0].app_instance_user_arn #=> String
resp.app_instance_user_endpoints[0].endpoint_id #=> String
resp.app_instance_user_endpoints[0].name #=> String
resp.app_instance_user_endpoints[0].type #=> String, one of "APNS", "APNS_SANDBOX", "GCM"
resp.app_instance_user_endpoints[0].allow_messages #=> String, one of "ALL", "NONE"
resp.app_instance_user_endpoints[0].endpoint_state.status #=> String, one of "ACTIVE", "INACTIVE"
resp.app_instance_user_endpoints[0].endpoint_state.status_reason #=> String, one of "INVALID_DEVICE_TOKEN", "INVALID_PINPOINT_ARN"
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_user_arn (required, String)

    The ARN of the ‘AppInstanceUser`.

  • :max_results (Integer)

    The maximum number of endpoints that you want to return.

  • :next_token (String)

    The token passed by previous API calls until all requested endpoints are returned.

Returns:

See Also:



1178
1179
1180
1181
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1178

def list_app_instance_user_endpoints(params = {}, options = {})
  req = build_request(:list_app_instance_user_endpoints, params)
  req.send_request(options)
end

#list_app_instance_users(params = {}) ⇒ Types::ListAppInstanceUsersResponse

List all ‘AppInstanceUsers` created under a single `AppInstance`.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_app_instance_users({
  app_instance_arn: "ChimeArn", # required
  max_results: 1,
  next_token: "NextToken",
})

Response structure


resp.app_instance_arn #=> String
resp.app_instance_users #=> Array
resp.app_instance_users[0].app_instance_user_arn #=> String
resp.app_instance_users[0].name #=> String
resp.app_instance_users[0]. #=> String
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_arn (required, String)

    The ARN of the ‘AppInstance`.

  • :max_results (Integer)

    The maximum number of requests that you want returned.

  • :next_token (String)

    The token passed by previous API calls until all requested users are returned.

Returns:

See Also:



1224
1225
1226
1227
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1224

def list_app_instance_users(params = {}, options = {})
  req = build_request(:list_app_instance_users, params)
  req.send_request(options)
end

#list_app_instances(params = {}) ⇒ Types::ListAppInstancesResponse

Lists all Amazon Chime ‘AppInstance`s created under a single AWS account.

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_app_instances({
  max_results: 1,
  next_token: "NextToken",
})

Response structure


resp.app_instances #=> Array
resp.app_instances[0].app_instance_arn #=> String
resp.app_instances[0].name #=> String
resp.app_instances[0]. #=> String
resp.next_token #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :max_results (Integer)

    The maximum number of ‘AppInstance`s that you want to return.

  • :next_token (String)

    The token passed by previous API requests until you reach the maximum number of ‘AppInstances`.

Returns:

See Also:



1265
1266
1267
1268
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1265

def list_app_instances(params = {}, options = {})
  req = build_request(:list_app_instances, params)
  req.send_request(options)
end

#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse

Lists the tags applied to an Amazon Chime SDK identity resource.

Examples:

Request syntax with placeholder values


resp = client.list_tags_for_resource({
  resource_arn: "ChimeArn", # required
})

Response structure


resp.tags #=> Array
resp.tags[0].key #=> String
resp.tags[0].value #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The ARN of the resource.

Returns:

See Also:



1295
1296
1297
1298
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1295

def list_tags_for_resource(params = {}, options = {})
  req = build_request(:list_tags_for_resource, params)
  req.send_request(options)
end

#put_app_instance_retention_settings(params = {}) ⇒ Types::PutAppInstanceRetentionSettingsResponse

Sets the amount of time in days that a given ‘AppInstance` retains data.

Examples:

Request syntax with placeholder values


resp = client.put_app_instance_retention_settings({
  app_instance_arn: "ChimeArn", # required
  app_instance_retention_settings: { # required
    channel_retention_settings: {
      retention_days: 1,
    },
  },
})

Response structure


resp.app_instance_retention_settings.channel_retention_settings.retention_days #=> Integer
resp.initiate_deletion_timestamp #=> Time

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_arn (required, String)

    The ARN of the ‘AppInstance`.

  • :app_instance_retention_settings (required, Types::AppInstanceRetentionSettings)

    The time in days to retain data. Data type: number.

Returns:

See Also:



1334
1335
1336
1337
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1334

def put_app_instance_retention_settings(params = {}, options = {})
  req = build_request(:put_app_instance_retention_settings, params)
  req.send_request(options)
end

#put_app_instance_user_expiration_settings(params = {}) ⇒ Types::PutAppInstanceUserExpirationSettingsResponse

Sets the number of days before the ‘AppInstanceUser` is automatically deleted.

<note markdown=“1”> A background process deletes expired ‘AppInstanceUsers` within 6 hours of expiration. Actual deletion times may vary.

Expired `AppInstanceUsers` that have not yet been deleted appear as

active, and you can update their expiration settings. The system honors the new settings.

</note>

Examples:

Request syntax with placeholder values


resp = client.put_app_instance_user_expiration_settings({
  app_instance_user_arn: "ChimeArn", # required
  expiration_settings: {
    expiration_days: 1, # required
    expiration_criterion: "CREATED_TIMESTAMP", # required, accepts CREATED_TIMESTAMP
  },
})

Response structure


resp.app_instance_user_arn #=> String
resp.expiration_settings.expiration_days #=> Integer
resp.expiration_settings.expiration_criterion #=> String, one of "CREATED_TIMESTAMP"

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_user_arn (required, String)

    The ARN of the ‘AppInstanceUser`.

  • :expiration_settings (Types::ExpirationSettings)

    Settings that control the interval after which an ‘AppInstanceUser` is automatically deleted.

Returns:

See Also:



1383
1384
1385
1386
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1383

def put_app_instance_user_expiration_settings(params = {}, options = {})
  req = build_request(:put_app_instance_user_expiration_settings, params)
  req.send_request(options)
end

#register_app_instance_user_endpoint(params = {}) ⇒ Types::RegisterAppInstanceUserEndpointResponse

Registers an endpoint under an Amazon Chime ‘AppInstanceUser`. The endpoint receives messages for a user. For push notifications, the endpoint is a mobile device used to receive mobile push notifications for a user.

Examples:

Request syntax with placeholder values


resp = client.register_app_instance_user_endpoint({
  app_instance_user_arn: "SensitiveChimeArn", # required
  name: "SensitiveString1600",
  type: "APNS", # required, accepts APNS, APNS_SANDBOX, GCM
  resource_arn: "ChimeArn", # required
  endpoint_attributes: { # required
    device_token: "NonEmptySensitiveString1600", # required
    voip_device_token: "NonEmptySensitiveString1600",
  },
  client_request_token: "ClientRequestToken", # required
  allow_messages: "ALL", # accepts ALL, NONE
})

Response structure


resp.app_instance_user_arn #=> String
resp.endpoint_id #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_user_arn (required, String)

    The ARN of the ‘AppInstanceUser`.

  • :name (String)

    The name of the ‘AppInstanceUserEndpoint`.

  • :type (required, String)

    The type of the ‘AppInstanceUserEndpoint`. Supported types:

    • ‘APNS`: The mobile notification service for an Apple device.

    • ‘APNS_SANDBOX`: The sandbox environment of the mobile notification service for an Apple device.

    • ‘GCM`: The mobile notification service for an Android device.

    Populate the ‘ResourceArn` value of each type as `PinpointAppArn`.

  • :resource_arn (required, String)

    The ARN of the resource to which the endpoint belongs.

  • :endpoint_attributes (required, Types::EndpointAttributes)

    The attributes of an ‘Endpoint`.

  • :client_request_token (required, String)

    The unique ID assigned to the request. Use different tokens to register other endpoints.

    **A suitable default value is auto-generated.** You should normally not need to pass this option.**

  • :allow_messages (String)

    Boolean that controls whether the AppInstanceUserEndpoint is opted in to receive messages. ‘ALL` indicates the endpoint receives all messages. `NONE` indicates the endpoint receives no messages.

Returns:

See Also:



1458
1459
1460
1461
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1458

def register_app_instance_user_endpoint(params = {}, options = {})
  req = build_request(:register_app_instance_user_endpoint, params)
  req.send_request(options)
end

#tag_resource(params = {}) ⇒ Struct

Applies the specified tags to the specified Amazon Chime SDK identity resource.

Examples:

Request syntax with placeholder values


resp = client.tag_resource({
  resource_arn: "ChimeArn", # required
  tags: [ # required
    {
      key: "TagKey", # required
      value: "TagValue", # required
    },
  ],
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The resource ARN.

  • :tags (required, Array<Types::Tag>)

    The tag key-value pairs.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1490
1491
1492
1493
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1490

def tag_resource(params = {}, options = {})
  req = build_request(:tag_resource, params)
  req.send_request(options)
end

#untag_resource(params = {}) ⇒ Struct

Removes the specified tags from the specified Amazon Chime SDK identity resource.

Examples:

Request syntax with placeholder values


resp = client.untag_resource({
  resource_arn: "ChimeArn", # required
  tag_keys: ["TagKey"], # required
})

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :resource_arn (required, String)

    The resource ARN.

  • :tag_keys (required, Array<String>)

    The tag keys.

Returns:

  • (Struct)

    Returns an empty response.

See Also:



1517
1518
1519
1520
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1517

def untag_resource(params = {}, options = {})
  req = build_request(:untag_resource, params)
  req.send_request(options)
end

#update_app_instance(params = {}) ⇒ Types::UpdateAppInstanceResponse

Updates ‘AppInstance` metadata.

Examples:

Request syntax with placeholder values


resp = client.update_app_instance({
  app_instance_arn: "ChimeArn", # required
  name: "NonEmptyResourceName", # required
  metadata: "Metadata", # required
})

Response structure


resp.app_instance_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_arn (required, String)

    The ARN of the ‘AppInstance`.

  • :name (required, String)

    The name that you want to change.

  • :metadata (required, String)

    The metadata that you want to change.

Returns:

See Also:



1553
1554
1555
1556
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1553

def update_app_instance(params = {}, options = {})
  req = build_request(:update_app_instance, params)
  req.send_request(options)
end

#update_app_instance_bot(params = {}) ⇒ Types::UpdateAppInstanceBotResponse

Updates the name and metadata of an ‘AppInstanceBot`.

Examples:

Request syntax with placeholder values


resp = client.update_app_instance_bot({
  app_instance_bot_arn: "ChimeArn", # required
  name: "ResourceName", # required
  metadata: "Metadata", # required
  configuration: {
    lex: { # required
      responds_to: "STANDARD_MESSAGES", # accepts STANDARD_MESSAGES
      invoked_by: {
        standard_messages: "AUTO", # required, accepts AUTO, ALL, MENTIONS, NONE
        targeted_messages: "ALL", # required, accepts ALL, NONE
      },
      lex_bot_alias_arn: "LexBotAliasArn", # required
      locale_id: "String", # required
      welcome_intent: "LexIntentName",
    },
  },
})

Response structure


resp.app_instance_bot_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_bot_arn (required, String)

    The ARN of the ‘AppInstanceBot`.

  • :name (required, String)

    The name of the ‘AppInstanceBot`.

  • :metadata (required, String)

    The metadata of the ‘AppInstanceBot`.

  • :configuration (Types::Configuration)

    The configuration for the bot update.

Returns:

See Also:



1604
1605
1606
1607
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1604

def update_app_instance_bot(params = {}, options = {})
  req = build_request(:update_app_instance_bot, params)
  req.send_request(options)
end

#update_app_instance_user(params = {}) ⇒ Types::UpdateAppInstanceUserResponse

Updates the details of an ‘AppInstanceUser`. You can update names and metadata.

Examples:

Request syntax with placeholder values


resp = client.update_app_instance_user({
  app_instance_user_arn: "ChimeArn", # required
  name: "UserName", # required
  metadata: "Metadata", # required
})

Response structure


resp.app_instance_user_arn #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_user_arn (required, String)

    The ARN of the ‘AppInstanceUser`.

  • :name (required, String)

    The name of the ‘AppInstanceUser`.

  • :metadata (required, String)

    The metadata of the ‘AppInstanceUser`.

Returns:

See Also:



1641
1642
1643
1644
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1641

def update_app_instance_user(params = {}, options = {})
  req = build_request(:update_app_instance_user, params)
  req.send_request(options)
end

#update_app_instance_user_endpoint(params = {}) ⇒ Types::UpdateAppInstanceUserEndpointResponse

Updates the details of an ‘AppInstanceUserEndpoint`. You can update the name and `AllowMessage` values.

Examples:

Request syntax with placeholder values


resp = client.update_app_instance_user_endpoint({
  app_instance_user_arn: "ChimeArn", # required
  endpoint_id: "String64", # required
  name: "SensitiveString1600",
  allow_messages: "ALL", # accepts ALL, NONE
})

Response structure


resp.app_instance_user_arn #=> String
resp.endpoint_id #=> String

Parameters:

  • params (Hash) (defaults to: {})

    ({})

Options Hash (params):

  • :app_instance_user_arn (required, String)

    The ARN of the ‘AppInstanceUser`.

  • :endpoint_id (required, String)

    The unique identifier of the ‘AppInstanceUserEndpoint`.

  • :name (String)

    The name of the ‘AppInstanceUserEndpoint`.

  • :allow_messages (String)

    Boolean that controls whether the ‘AppInstanceUserEndpoint` is opted in to receive messages. `ALL` indicates the endpoint will receive all messages. `NONE` indicates the endpoint will receive no messages.

Returns:

See Also:



1686
1687
1688
1689
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1686

def update_app_instance_user_endpoint(params = {}, options = {})
  req = build_request(:update_app_instance_user_endpoint, params)
  req.send_request(options)
end

#waiter_namesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


1715
1716
1717
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1715

def waiter_names
  []
end