Class: Aws::ChimeSDKIdentity::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ChimeSDKIdentity::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-chimesdkidentity/client.rb
Overview
An API client for ChimeSDKIdentity. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ChimeSDKIdentity::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_app_instance(params = {}) ⇒ Types::CreateAppInstanceResponse
Creates an Amazon Chime SDK messaging ‘AppInstance` under an AWS account.
-
#create_app_instance_admin(params = {}) ⇒ Types::CreateAppInstanceAdminResponse
Promotes an ‘AppInstanceUser` or `AppInstanceBot` to an `AppInstanceAdmin`.
-
#create_app_instance_bot(params = {}) ⇒ Types::CreateAppInstanceBotResponse
Creates a bot under an Amazon Chime ‘AppInstance`.
-
#create_app_instance_user(params = {}) ⇒ Types::CreateAppInstanceUserResponse
Creates a user under an Amazon Chime ‘AppInstance`.
-
#delete_app_instance(params = {}) ⇒ Struct
Deletes an ‘AppInstance` and all associated data asynchronously.
-
#delete_app_instance_admin(params = {}) ⇒ Struct
Demotes an ‘AppInstanceAdmin` to an `AppInstanceUser` or `AppInstanceBot`.
-
#delete_app_instance_bot(params = {}) ⇒ Struct
Deletes an ‘AppInstanceBot`.
-
#delete_app_instance_user(params = {}) ⇒ Struct
Deletes an ‘AppInstanceUser`.
-
#deregister_app_instance_user_endpoint(params = {}) ⇒ Struct
Deregisters an ‘AppInstanceUserEndpoint`.
-
#describe_app_instance(params = {}) ⇒ Types::DescribeAppInstanceResponse
Returns the full details of an ‘AppInstance`.
-
#describe_app_instance_admin(params = {}) ⇒ Types::DescribeAppInstanceAdminResponse
Returns the full details of an ‘AppInstanceAdmin`.
-
#describe_app_instance_bot(params = {}) ⇒ Types::DescribeAppInstanceBotResponse
The ‘AppInstanceBot’s` information.
-
#describe_app_instance_user(params = {}) ⇒ Types::DescribeAppInstanceUserResponse
Returns the full details of an ‘AppInstanceUser`.
-
#describe_app_instance_user_endpoint(params = {}) ⇒ Types::DescribeAppInstanceUserEndpointResponse
Returns the full details of an ‘AppInstanceUserEndpoint`.
-
#get_app_instance_retention_settings(params = {}) ⇒ Types::GetAppInstanceRetentionSettingsResponse
Gets the retention settings for an ‘AppInstance`.
-
#list_app_instance_admins(params = {}) ⇒ Types::ListAppInstanceAdminsResponse
Returns a list of the administrators in the ‘AppInstance`.
-
#list_app_instance_bots(params = {}) ⇒ Types::ListAppInstanceBotsResponse
Lists all ‘AppInstanceBots` created under a single `AppInstance`.
-
#list_app_instance_user_endpoints(params = {}) ⇒ Types::ListAppInstanceUserEndpointsResponse
Lists all the ‘AppInstanceUserEndpoints` created under a single `AppInstanceUser`.
-
#list_app_instance_users(params = {}) ⇒ Types::ListAppInstanceUsersResponse
List all ‘AppInstanceUsers` created under a single `AppInstance`.
-
#list_app_instances(params = {}) ⇒ Types::ListAppInstancesResponse
Lists all Amazon Chime ‘AppInstance`s created under a single AWS account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags applied to an Amazon Chime SDK identity resource.
-
#put_app_instance_retention_settings(params = {}) ⇒ Types::PutAppInstanceRetentionSettingsResponse
Sets the amount of time in days that a given ‘AppInstance` retains data.
-
#put_app_instance_user_expiration_settings(params = {}) ⇒ Types::PutAppInstanceUserExpirationSettingsResponse
Sets the number of days before the ‘AppInstanceUser` is automatically deleted.
-
#register_app_instance_user_endpoint(params = {}) ⇒ Types::RegisterAppInstanceUserEndpointResponse
Registers an endpoint under an Amazon Chime ‘AppInstanceUser`.
-
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified Amazon Chime SDK identity resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified Amazon Chime SDK identity resource.
-
#update_app_instance(params = {}) ⇒ Types::UpdateAppInstanceResponse
Updates ‘AppInstance` metadata.
-
#update_app_instance_bot(params = {}) ⇒ Types::UpdateAppInstanceBotResponse
Updates the name and metadata of an ‘AppInstanceBot`.
-
#update_app_instance_user(params = {}) ⇒ Types::UpdateAppInstanceUserResponse
Updates the details of an ‘AppInstanceUser`.
-
#update_app_instance_user_endpoint(params = {}) ⇒ Types::UpdateAppInstanceUserEndpointResponse
Updates the details of an ‘AppInstanceUserEndpoint`.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1722 1723 1724 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1722 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1725 1726 1727 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1725 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1695 1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1695 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ChimeSDKIdentity') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-chimesdkidentity' context[:gem_version] = '1.53.0' Seahorse::Client::Request.new(handlers, context) end |
#create_app_instance(params = {}) ⇒ Types::CreateAppInstanceResponse
Creates an Amazon Chime SDK messaging ‘AppInstance` under an AWS account. Only SDK messaging customers use this API. `CreateAppInstance` supports idempotency behavior as described in the AWS API Standard.
identity
528 529 530 531 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 528 def create_app_instance(params = {}, = {}) req = build_request(:create_app_instance, params) req.send_request() end |
#create_app_instance_admin(params = {}) ⇒ Types::CreateAppInstanceAdminResponse
Promotes an ‘AppInstanceUser` or `AppInstanceBot` to an `AppInstanceAdmin`. The promoted entity can perform the following actions.
-
‘ChannelModerator` actions across all channels in the `AppInstance`.
-
‘DeleteChannelMessage` actions.
Only an ‘AppInstanceUser` and `AppInstanceBot` can be promoted to an `AppInstanceAdmin` role.
572 573 574 575 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 572 def create_app_instance_admin(params = {}, = {}) req = build_request(:create_app_instance_admin, params) req.send_request() end |
#create_app_instance_bot(params = {}) ⇒ Types::CreateAppInstanceBotResponse
Creates a bot under an Amazon Chime ‘AppInstance`. The request consists of a unique `Configuration` and `Name` for that bot.
641 642 643 644 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 641 def create_app_instance_bot(params = {}, = {}) req = build_request(:create_app_instance_bot, params) req.send_request() end |
#create_app_instance_user(params = {}) ⇒ Types::CreateAppInstanceUserResponse
Creates a user under an Amazon Chime ‘AppInstance`. The request consists of a unique `appInstanceUserId` and `Name` for that user.
707 708 709 710 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 707 def create_app_instance_user(params = {}, = {}) req = build_request(:create_app_instance_user, params) req.send_request() end |
#delete_app_instance(params = {}) ⇒ Struct
Deletes an ‘AppInstance` and all associated data asynchronously.
729 730 731 732 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 729 def delete_app_instance(params = {}, = {}) req = build_request(:delete_app_instance, params) req.send_request() end |
#delete_app_instance_admin(params = {}) ⇒ Struct
Demotes an ‘AppInstanceAdmin` to an `AppInstanceUser` or `AppInstanceBot`. This action does not delete the user.
756 757 758 759 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 756 def delete_app_instance_admin(params = {}, = {}) req = build_request(:delete_app_instance_admin, params) req.send_request() end |
#delete_app_instance_bot(params = {}) ⇒ Struct
Deletes an ‘AppInstanceBot`.
778 779 780 781 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 778 def delete_app_instance_bot(params = {}, = {}) req = build_request(:delete_app_instance_bot, params) req.send_request() end |
#delete_app_instance_user(params = {}) ⇒ Struct
Deletes an ‘AppInstanceUser`.
800 801 802 803 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 800 def delete_app_instance_user(params = {}, = {}) req = build_request(:delete_app_instance_user, params) req.send_request() end |
#deregister_app_instance_user_endpoint(params = {}) ⇒ Struct
Deregisters an ‘AppInstanceUserEndpoint`.
826 827 828 829 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 826 def deregister_app_instance_user_endpoint(params = {}, = {}) req = build_request(:deregister_app_instance_user_endpoint, params) req.send_request() end |
#describe_app_instance(params = {}) ⇒ Types::DescribeAppInstanceResponse
Returns the full details of an ‘AppInstance`.
858 859 860 861 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 858 def describe_app_instance(params = {}, = {}) req = build_request(:describe_app_instance, params) req.send_request() end |
#describe_app_instance_admin(params = {}) ⇒ Types::DescribeAppInstanceAdminResponse
Returns the full details of an ‘AppInstanceAdmin`.
893 894 895 896 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 893 def describe_app_instance_admin(params = {}, = {}) req = build_request(:describe_app_instance_admin, params) req.send_request() end |
#describe_app_instance_bot(params = {}) ⇒ Types::DescribeAppInstanceBotResponse
The ‘AppInstanceBot’s` information.
931 932 933 934 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 931 def describe_app_instance_bot(params = {}, = {}) req = build_request(:describe_app_instance_bot, params) req.send_request() end |
#describe_app_instance_user(params = {}) ⇒ Types::DescribeAppInstanceUserResponse
Returns the full details of an ‘AppInstanceUser`.
965 966 967 968 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 965 def describe_app_instance_user(params = {}, = {}) req = build_request(:describe_app_instance_user, params) req.send_request() end |
#describe_app_instance_user_endpoint(params = {}) ⇒ Types::DescribeAppInstanceUserEndpointResponse
Returns the full details of an ‘AppInstanceUserEndpoint`.
1008 1009 1010 1011 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1008 def describe_app_instance_user_endpoint(params = {}, = {}) req = build_request(:describe_app_instance_user_endpoint, params) req.send_request() end |
#get_app_instance_retention_settings(params = {}) ⇒ Types::GetAppInstanceRetentionSettingsResponse
Gets the retention settings for an ‘AppInstance`.
1038 1039 1040 1041 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1038 def get_app_instance_retention_settings(params = {}, = {}) req = build_request(:get_app_instance_retention_settings, params) req.send_request() end |
#list_app_instance_admins(params = {}) ⇒ Types::ListAppInstanceAdminsResponse
Returns a list of the administrators in the ‘AppInstance`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1083 1084 1085 1086 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1083 def list_app_instance_admins(params = {}, = {}) req = build_request(:list_app_instance_admins, params) req.send_request() end |
#list_app_instance_bots(params = {}) ⇒ Types::ListAppInstanceBotsResponse
Lists all ‘AppInstanceBots` created under a single `AppInstance`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1129 1130 1131 1132 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1129 def list_app_instance_bots(params = {}, = {}) req = build_request(:list_app_instance_bots, params) req.send_request() end |
#list_app_instance_user_endpoints(params = {}) ⇒ Types::ListAppInstanceUserEndpointsResponse
Lists all the ‘AppInstanceUserEndpoints` created under a single `AppInstanceUser`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1178 1179 1180 1181 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1178 def list_app_instance_user_endpoints(params = {}, = {}) req = build_request(:list_app_instance_user_endpoints, params) req.send_request() end |
#list_app_instance_users(params = {}) ⇒ Types::ListAppInstanceUsersResponse
List all ‘AppInstanceUsers` created under a single `AppInstance`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1224 1225 1226 1227 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1224 def list_app_instance_users(params = {}, = {}) req = build_request(:list_app_instance_users, params) req.send_request() end |
#list_app_instances(params = {}) ⇒ Types::ListAppInstancesResponse
Lists all Amazon Chime ‘AppInstance`s created under a single AWS account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1265 1266 1267 1268 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1265 def list_app_instances(params = {}, = {}) req = build_request(:list_app_instances, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags applied to an Amazon Chime SDK identity resource.
1295 1296 1297 1298 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1295 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_app_instance_retention_settings(params = {}) ⇒ Types::PutAppInstanceRetentionSettingsResponse
Sets the amount of time in days that a given ‘AppInstance` retains data.
1334 1335 1336 1337 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1334 def put_app_instance_retention_settings(params = {}, = {}) req = build_request(:put_app_instance_retention_settings, params) req.send_request() end |
#put_app_instance_user_expiration_settings(params = {}) ⇒ Types::PutAppInstanceUserExpirationSettingsResponse
Sets the number of days before the ‘AppInstanceUser` is automatically deleted.
<note markdown=“1”> A background process deletes expired ‘AppInstanceUsers` within 6 hours of expiration. Actual deletion times may vary.
Expired `AppInstanceUsers` that have not yet been deleted appear as
active, and you can update their expiration settings. The system honors the new settings.
</note>
1383 1384 1385 1386 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1383 def put_app_instance_user_expiration_settings(params = {}, = {}) req = build_request(:put_app_instance_user_expiration_settings, params) req.send_request() end |
#register_app_instance_user_endpoint(params = {}) ⇒ Types::RegisterAppInstanceUserEndpointResponse
Registers an endpoint under an Amazon Chime ‘AppInstanceUser`. The endpoint receives messages for a user. For push notifications, the endpoint is a mobile device used to receive mobile push notifications for a user.
1458 1459 1460 1461 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1458 def register_app_instance_user_endpoint(params = {}, = {}) req = build_request(:register_app_instance_user_endpoint, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified Amazon Chime SDK identity resource.
1490 1491 1492 1493 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1490 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified Amazon Chime SDK identity resource.
1517 1518 1519 1520 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1517 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_app_instance(params = {}) ⇒ Types::UpdateAppInstanceResponse
Updates ‘AppInstance` metadata.
1553 1554 1555 1556 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1553 def update_app_instance(params = {}, = {}) req = build_request(:update_app_instance, params) req.send_request() end |
#update_app_instance_bot(params = {}) ⇒ Types::UpdateAppInstanceBotResponse
Updates the name and metadata of an ‘AppInstanceBot`.
1604 1605 1606 1607 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1604 def update_app_instance_bot(params = {}, = {}) req = build_request(:update_app_instance_bot, params) req.send_request() end |
#update_app_instance_user(params = {}) ⇒ Types::UpdateAppInstanceUserResponse
Updates the details of an ‘AppInstanceUser`. You can update names and metadata.
1641 1642 1643 1644 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1641 def update_app_instance_user(params = {}, = {}) req = build_request(:update_app_instance_user, params) req.send_request() end |
#update_app_instance_user_endpoint(params = {}) ⇒ Types::UpdateAppInstanceUserEndpointResponse
Updates the details of an ‘AppInstanceUserEndpoint`. You can update the name and `AllowMessage` values.
1686 1687 1688 1689 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1686 def update_app_instance_user_endpoint(params = {}, = {}) req = build_request(:update_app_instance_user_endpoint, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1715 1716 1717 |
# File 'lib/aws-sdk-chimesdkidentity/client.rb', line 1715 def waiter_names [] end |